@@ -67,7 +67,7 @@ CK_CPPSTART
 
 #define CHECK_MAJOR_VERSION (0)
 #define CHECK_MINOR_VERSION (9)
-#define CHECK_MICRO_VERSION (4)
+#define CHECK_MICRO_VERSION (5)
 
 extern int check_major_version;
 extern int check_minor_version;
@@ -174,7 +174,7 @@ void tcase_fn_start (const char *fname, const char *file, int line);
    One must use braces within a START_/END_ pair to declare new variables
 */ 
 #define START_TEST(__testname)\
-static void __testname (int i __attribute__((unused)))\
+static void __testname (int _i __attribute__((unused)))\
 {\
   tcase_fn_start (""# __testname, __FILE__, __LINE__);
 
